@@ -28,7 +28,7 @@ from email import charset
 charset.add_charset('utf-8', None)
 emlpolicy = email.policy.EmailPolicy(utf8=True, cte_type='8bit', max_line_length=None)
 
-__VERSION__ = '0.5.3'
+__VERSION__ = '0.5.4'
 ATTESTATION_FORMAT_VER = '0.1'
 
 logger = logging.getLogger('b4')
@@ -833,7 +833,12 @@ class LoreMessage:
         except IndexError:
             pass
 
-        self.date = email.utils.parsedate_to_datetime(str(self.msg['Date']))
+        msgdate = self.msg.get('Date')
+        if msgdate:
+            self.date = email.utils.parsedate_to_datetime(str(msgdate))
+        else:
+            # An email without a Date: field?
+            self.date = datetime.datetime.now()
 
         diffre = re.compile(r'^(---.*\n\+\+\+|GIT binary patch|diff --git \w/\S+ \w/\S+)', re.M | re.I)
         diffstatre = re.compile(r'^\s*\d+ file.*\d+ (insertion|deletion)', re.M | re.I)
